BindError

Enum BindError 

#[non_exhaustive]
pub enum BindError { MissingVariable { name: VariableName, }, EmptyVariable { name: VariableName, }, Environment { name: VariableName, source: EnvironmentError, }, InvalidBoolean { name: VariableName, }, ParseVariable { name: VariableName, expected: &'static str, }, Validation { name: VariableName, message: String, }, ValueTooLarge { name: VariableName, max_bytes: usize, }, }
Binding failure for one environment variable.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingVariable

Required variable missing.

Fields

name: VariableName

Environment variable name.



EmptyVariable

Required variable empty.

Fields

name: VariableName

Environment variable name.



Environment

Environment adapter failed during variable read.

Fields

name: VariableName

Environment variable name.

source: EnvironmentError

Adapter failure.



InvalidBoolean

Boolean value invalid.

Fields

name: VariableName

Environment variable name.



ParseVariable

Parsed value invalid for the expected type.

Fields

name: VariableName

Environment variable name.

expected: &'static str

Expected type text.



Validation

Value failed validation.

Fields

name: VariableName

Environment variable name.

message: String

Safe validation detail.



ValueTooLarge

Raw value exceeded the configured byte limit.

Fields

name: VariableName

Environment variable name.

max_bytes: usize

Maximum accepted byte count.

Implementations

Source

impl BindError

pub fn missing(name: impl Into<VariableName>) -> Self

Build a missing-variable error.

pub fn empty(name: impl Into<VariableName>) -> Self

Build an empty-variable error.

pub fn environment( name: impl Into<VariableName>, source: EnvironmentError, ) -> Self

Build an environment adapter error.

pub fn invalid_boolean(name: impl Into<VariableName>) -> Self

Build a boolean parse error.

pub fn parse(name: impl Into<VariableName>, expected: &'static str) -> Self

Build a typed parse error.

pub fn validation(name: impl Into<VariableName>, error: ValidationError) -> Self

Build a validation error.

pub fn validation_with_sensitivity( name: impl Into<VariableName>, error: ValidationError, sensitive: bool, ) -> Self

Build a validation error, hiding custom details for sensitive values.

pub fn value_too_large(name: impl Into<VariableName>, max_bytes: usize) -> Self

Build a value-size limit error.

pub fn variable_name(&self) -> &str

Return the environment variable name associated with the error.

pub fn error_code(&self) -> &'static str

Return a stable error code.